@@ -105,7 +105,7 @@ discrete.loss.node = function(node, fitted, data, debug = FALSE) {
     if (length(parents) == 1)
       config = minimal.data.frame.column(data, parents)
     else
-      config = raw.configurations(minimal.data.frame.column(data, parents))
+      config = configurations(minimal.data.frame.column(data, parents), factor = FALSE)
 
     l = .Call("cdloss",
               fitted = fitted[[node]],
